@@ -34,14 +34,14 @@ class FactorUCB(AbstractRanker):
         self.Theta_v = self.Theta[:, self.k:]
         self.W = np.identity(n=self.dataObj.n_users)
 
-        self.A = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
+        # self.A = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
         # self.A = np.zeros((self.dataObj.n_users, self.lambda_1 * np.identity(n=(self.k+self.l)*self.dataObj.n_users)))
         self.AInv = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
         # self.AInv = np.zeros((self.dataObj.n_users, self.lambda_1 * np.identity(n=(self.k + self.l) * self.dataObj.n_users)))
         identity = self.lambda_1 * np.identity(n=(self.k+self.l)*self.dataObj.n_users)
-        for i in range(self.A.shape[0]):
-            self.A[i] = identity
-            self.AInv[i] = np.linalg.inv(self.A[i])  # np.zeros((self.k+self.l,self.k+self.l))
+        for i in range(self.AInv.shape[0]):
+            # self.A[i] = identity
+            self.AInv[i] = np.linalg.inv(identity)  # np.zeros((self.k+self.l,self.k+self.l))
         self.b = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
 
         self.C = np.zeros((self.dataObj.n_items, self.l, self.l))
@@ -53,10 +53,10 @@ class FactorUCB(AbstractRanker):
 
         self.ill_matrix_counter = 0
         # for ill inverse
-        self.AInv_tmp = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
-        self.b_tmp = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
-        self.CInv_tmp = np.zeros((self.dataObj.n_items, self.l, self.l))
-        self.d_tmp = np.zeros((self.dataObj.n_items, self.l))
+        # self.AInv_tmp = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
+        # self.b_tmp = np.zeros((self.dataObj.n_users, (self.k+self.l)*self.dataObj.n_users))
+        # self.CInv_tmp = np.zeros((self.dataObj.n_items, self.l, self.l))
+        # self.d_tmp = np.zeros((self.dataObj.n_items, self.l))
 
     def get_ranking(self, batch_users, sampled_items=None, round=None):
         """
@@ -134,7 +134,7 @@ class FactorUCB(AbstractRanker):
             self.AInv_tmp = np.dot(np.dot(AInv_xT, tmp_inv), AInv_xT.T)
             # MInv - the new part
             self.AInv[user] -= self.AInv_tmp
-            self.A[user] += self.sigma * _XVW.T.dot(_XVW)
+            # self.A[user] += self.sigma * _XVW.T.dot(_XVW)
 
             # for b: feedback
             # if self.processing_type == 'feature_weight':
