@@ -10,6 +10,9 @@ import sys
 import multiprocessing as mp
 from multiprocessing.pool import ThreadPool
 import itertools
+from sklearn.metrics.pairwise import cosine_similarity
+from scipy import sparse
+from sklearn.preprocessing import normalize
 
 ClickModel = {'cascade': CascadeModel}
 
@@ -85,7 +88,7 @@ class OnlineSimulator():
             # Compute rewards
             clicks, rewards = self.compute_rewards(args[3], args[4], args[0], rankings)
             # Update policy based on rewards
-            self.rankers[j]["ranker"].update(args[0], args[1], rankings, clicks, args[2], self.user_round)
+            self.rankers[j]["ranker"].update(args[0], rankings, clicks, args[2], self.user_round)
             self.overall_rewards[j, args[2]] = rewards.sum()
             # regret[j, i] = overall_optimal_reward.sum() - rewards.sum()
             # overall_rankings[j, i] = rankings
@@ -170,6 +173,25 @@ class OnlineSimulator():
                 delta[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][ranking]
                 optimal_scores[i, :] = self.user_features[i].dot(delta.T)
             return optimal_rankings, optimal_scores
+        elif config.optimal_ranker == 'item_similarity':
+            self.item_sim_matrix = cosine_similarity(dataObj.test_data.T)
+            np.fill_diagonal(self.item_sim_matrix, 0)
+            probs = dataObj.test_data.dot(self.item_sim_matrix)
+            # probs = (probs-np.min(probs))/(np.max(probs)-np.min(probs))
+            # self.similarity_prob = probs/np.sqrt(np.sum(probs**2))
+            # self.similarity_probs = normalize(probs, axis=1, norm='l1')
+            row_max = np.tile(np.amax(probs, axis=1).reshape(dataObj.test_data.shape[0],1), (1,dataObj.test_data.shape[1]))
+            row_min = np.tile(np.amin(probs, axis=1).reshape(dataObj.test_data.shape[0],1), (1,dataObj.test_data.shape[1]))
+            self.similarity_probs = (probs - row_min) / (row_max - row_min)
+            optimal_rankings = np.argsort(-self.similarity_probs)[:, :config.list_size]
+            # batch_item_features = np.take(self.item_sim_matrix, optimal_rankings, axis=0)
+            n_users = dataObj.n_users #self.user_features.shape[0]
+            optimal_scores = np.zeros((n_users, config.list_size))
+            # th_reward = np.zeros(n_users)
+            for i in range(n_users):
+                # optimal_scores[i] = dataObj.test_data[i].dot(batch_item_features[i].T)
+                optimal_scores[i] = self.similarity_probs[i,optimal_rankings[i]]
+            return optimal_rankings, optimal_scores
 
     def compute_rewards(self, config, dataObj, batch_users, rankings):
         batch_user_features = np.take(self.user_features, batch_users, axis=0)
@@ -205,6 +227,12 @@ class OnlineSimulator():
                 item_full_feature[:, item_topic.shape[1]:] = item_latent[rankings[i]]
                 scores[i] = batch_user_features[i].dot(item_full_feature.T)
             return self.click_simulator.get_feedback(scores)
+        elif config.optimal_ranker == 'item_similarity':
+            n_users = len(batch_users)
+            scores = np.zeros((n_users, config.list_size))
+            for i in range(n_users):
+                scores[i] = self.similarity_probs[batch_users[i],rankings[i]]
+            return self.click_simulator.get_feedback(scores)
         # elif config.optimal_ranker == 'ears_hybrid':
         #     n_users = batch_user_features.shape[0]
         #     scores = np.zeros((n_users, config.list_size))
